# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetResolverFirewallRulesResult',
    'AwaitableGetResolverFirewallRulesResult',
    'get_resolver_firewall_rules',
    'get_resolver_firewall_rules_output',
]

@pulumi.output_type
class GetResolverFirewallRulesResult:
    """
    A collection of values returned by getResolverFirewallRules.
    """
    def __init__(__self__, action=None, firewall_rule_group_id=None, firewall_rules=None, id=None, priority=None):
        if action and not isinstance(action, str):
            raise TypeError("Expected argument 'action' to be a str")
        pulumi.set(__self__, "action", action)
        if firewall_rule_group_id and not isinstance(firewall_rule_group_id, str):
            raise TypeError("Expected argument 'firewall_rule_group_id' to be a str")
        pulumi.set(__self__, "firewall_rule_group_id", firewall_rule_group_id)
        if firewall_rules and not isinstance(firewall_rules, list):
            raise TypeError("Expected argument 'firewall_rules' to be a list")
        pulumi.set(__self__, "firewall_rules", firewall_rules)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)

    @property
    @pulumi.getter
    def action(self) -> Optional[str]:
        return pulumi.get(self, "action")

    @property
    @pulumi.getter(name="firewallRuleGroupId")
    def firewall_rule_group_id(self) -> str:
        return pulumi.get(self, "firewall_rule_group_id")

    @property
    @pulumi.getter(name="firewallRules")
    def firewall_rules(self) -> Sequence['outputs.GetResolverFirewallRulesFirewallRuleResult']:
        """
        List with information about the firewall rules. See details below.
        """
        return pulumi.get(self, "firewall_rules")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def priority(self) -> Optional[int]:
        return pulumi.get(self, "priority")


class AwaitableGetResolverFirewallRulesResult(GetResolverFirewallRulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetResolverFirewallRulesResult(
            action=self.action,
            firewall_rule_group_id=self.firewall_rule_group_id,
            firewall_rules=self.firewall_rules,
            id=self.id,
            priority=self.priority)


def get_resolver_firewall_rules(action: Optional[str] = None,
                                firewall_rule_group_id: Optional[str] = None,
                                priority: Optional[int] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetResolverFirewallRulesResult:
    """
    `route53.get_resolver_firewall_rules` Provides details about rules in a specific Route53 Resolver Firewall rule group.

    ## Example Usage

    The following example shows how to get Route53 Resolver Firewall rules based on its associated firewall group id.

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.route53.get_resolver_firewall_rules(firewall_rule_group_id=aws_route53_resolver_firewall_rule_group["example"]["id"])
    ```


    :param str action: The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list.
    :param str firewall_rule_group_id: The unique identifier of the firewall rule group that you want to retrieve the rules for.
    :param int priority: The setting that determines the processing order of the rules in a rule group.
    """
    __args__ = dict()
    __args__['action'] = action
    __args__['firewallRuleGroupId'] = firewall_rule_group_id
    __args__['priority'] = priority
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aws:route53/getResolverFirewallRules:getResolverFirewallRules', __args__, opts=opts, typ=GetResolverFirewallRulesResult).value

    return AwaitableGetResolverFirewallRulesResult(
        action=__ret__.action,
        firewall_rule_group_id=__ret__.firewall_rule_group_id,
        firewall_rules=__ret__.firewall_rules,
        id=__ret__.id,
        priority=__ret__.priority)


@_utilities.lift_output_func(get_resolver_firewall_rules)
def get_resolver_firewall_rules_output(action: Optional[pulumi.Input[Optional[str]]] = None,
                                       firewall_rule_group_id: Optional[pulumi.Input[str]] = None,
                                       priority: Optional[pulumi.Input[Optional[int]]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetResolverFirewallRulesResult]:
    """
    `route53.get_resolver_firewall_rules` Provides details about rules in a specific Route53 Resolver Firewall rule group.

    ## Example Usage

    The following example shows how to get Route53 Resolver Firewall rules based on its associated firewall group id.

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.route53.get_resolver_firewall_rules(firewall_rule_group_id=aws_route53_resolver_firewall_rule_group["example"]["id"])
    ```


    :param str action: The action that DNS Firewall should take on a DNS query when it matches one of the domains in the rule's domain list.
    :param str firewall_rule_group_id: The unique identifier of the firewall rule group that you want to retrieve the rules for.
    :param int priority: The setting that determines the processing order of the rules in a rule group.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetRouterConfigurationResult',
    'AwaitableGetRouterConfigurationResult',
    'get_router_configuration',
    'get_router_configuration_output',
]

@pulumi.output_type
class GetRouterConfigurationResult:
    """
    A collection of values returned by getRouterConfiguration.
    """
    def __init__(__self__, customer_router_config=None, id=None, router_type_identifier=None, routers=None, virtual_interface_id=None, virtual_interface_name=None):
        if customer_router_config and not isinstance(customer_router_config, str):
            raise TypeError("Expected argument 'customer_router_config' to be a str")
        pulumi.set(__self__, "customer_router_config", customer_router_config)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if router_type_identifier and not isinstance(router_type_identifier, str):
            raise TypeError("Expected argument 'router_type_identifier' to be a str")
        pulumi.set(__self__, "router_type_identifier", router_type_identifier)
        if routers and not isinstance(routers, list):
            raise TypeError("Expected argument 'routers' to be a list")
        pulumi.set(__self__, "routers", routers)
        if virtual_interface_id and not isinstance(virtual_interface_id, str):
            raise TypeError("Expected argument 'virtual_interface_id' to be a str")
        pulumi.set(__self__, "virtual_interface_id", virtual_interface_id)
        if virtual_interface_name and not isinstance(virtual_interface_name, str):
            raise TypeError("Expected argument 'virtual_interface_name' to be a str")
        pulumi.set(__self__, "virtual_interface_name", virtual_interface_name)

    @property
    @pulumi.getter(name="customerRouterConfig")
    def customer_router_config(self) -> str:
        """
        Instructions for configuring your router
        """
        return pulumi.get(self, "customer_router_config")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="routerTypeIdentifier")
    def router_type_identifier(self) -> str:
        """
        Router type identifier
        """
        return pulumi.get(self, "router_type_identifier")

    @property
    @pulumi.getter
    def routers(self) -> Sequence['outputs.GetRouterConfigurationRouterResult']:
        """
        Block of the router type details
        """
        return pulumi.get(self, "routers")

    @property
    @pulumi.getter(name="virtualInterfaceId")
    def virtual_interface_id(self) -> str:
        return pulumi.get(self, "virtual_interface_id")

    @property
    @pulumi.getter(name="virtualInterfaceName")
    def virtual_interface_name(self) -> str:
        return pulumi.get(self, "virtual_interface_name")


class AwaitableGetRouterConfigurationResult(GetRouterConfigurationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRouterConfigurationResult(
            customer_router_config=self.customer_router_config,
            id=self.id,
            router_type_identifier=self.router_type_identifier,
            routers=self.routers,
            virtual_interface_id=self.virtual_interface_id,
            virtual_interface_name=self.virtual_interface_name)


def get_router_configuration(router_type_identifier: Optional[str] = None,
                             virtual_interface_id: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRouterConfigurationResult:
    """
    Data source for retrieving Router Configuration instructions for a given AWS Direct Connect Virtual Interface and Router Type.

    ## Example Usage
    ### Basic Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.directconnect.get_router_configuration(router_type_identifier="CiscoSystemsInc-2900SeriesRouters-IOS124",
        virtual_interface_id="dxvif-abcde123")
    ```


    :param str router_type_identifier: ID of the Router Type. For example: `CiscoSystemsInc-2900SeriesRouters-IOS124`
    :param str virtual_interface_id: ID of the Direct Connect Virtual Interface
    """
    __args__ = dict()
    __args__['routerTypeIdentifier'] = router_type_identifier
    __args__['virtualInterfaceId'] = virtual_interface_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aws:directconnect/getRouterConfiguration:getRouterConfiguration', __args__, opts=opts, typ=GetRouterConfigurationResult).value

    return AwaitableGetRouterConfigurationResult(
        customer_router_config=__ret__.customer_router_config,
        id=__ret__.id,
        router_type_identifier=__ret__.router_type_identifier,
        routers=__ret__.routers,
        virtual_interface_id=__ret__.virtual_interface_id,
        virtual_interface_name=__ret__.virtual_interface_name)


@_utilities.lift_output_func(get_router_configuration)
def get_router_configuration_output(router_type_identifier: Optional[pulumi.Input[str]] = None,
                                    virtual_interface_id: Optional[pulumi.Input[str]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRouterConfigurationResult]:
    """
    Data source for retrieving Router Configuration instructions for a given AWS Direct Connect Virtual Interface and Router Type.

    ## Example Usage
    ### Basic Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.directconnect.get_router_configuration(router_type_identifier="CiscoSystemsInc-2900SeriesRouters-IOS124",
        virtual_interface_id="dxvif-abcde123")
    ```


    :param str router_type_identifier: ID of the Router Type. For example: `CiscoSystemsInc-2900SeriesRouters-IOS124`
    :param str virtual_interface_id: ID of the Direct Connect Virtual Interface
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GeoMatchSetArgs', 'GeoMatchSet']

@pulumi.input_type
class GeoMatchSetArgs:
    def __init__(__self__, *,
                 geo_match_constraints: Optional[pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a GeoMatchSet resource.
        :param pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]] geo_match_constraints: The Geo Match Constraint objects which contain the country that you want AWS WAF to search for.
        :param pulumi.Input[str] name: The name or description of the Geo Match Set.
        """
        if geo_match_constraints is not None:
            pulumi.set(__self__, "geo_match_constraints", geo_match_constraints)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="geoMatchConstraints")
    def geo_match_constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]]]:
        """
        The Geo Match Constraint objects which contain the country that you want AWS WAF to search for.
        """
        return pulumi.get(self, "geo_match_constraints")

    @geo_match_constraints.setter
    def geo_match_constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]]]):
        pulumi.set(self, "geo_match_constraints", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name or description of the Geo Match Set.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _GeoMatchSetState:
    def __init__(__self__, *,
                 geo_match_constraints: Optional[pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GeoMatchSet resources.
        :param pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]] geo_match_constraints: The Geo Match Constraint objects which contain the country that you want AWS WAF to search for.
        :param pulumi.Input[str] name: The name or description of the Geo Match Set.
        """
        if geo_match_constraints is not None:
            pulumi.set(__self__, "geo_match_constraints", geo_match_constraints)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="geoMatchConstraints")
    def geo_match_constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]]]:
        """
        The Geo Match Constraint objects which contain the country that you want AWS WAF to search for.
        """
        return pulumi.get(self, "geo_match_constraints")

    @geo_match_constraints.setter
    def geo_match_constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GeoMatchSetGeoMatchConstraintArgs']]]]):
        pulumi.set(self, "geo_match_constraints", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name or description of the Geo Match Set.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class GeoMatchSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 geo_match_constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GeoMatchSetGeoMatchConstraintArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a WAF Regional Geo Match Set Resource

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        geo_match_set = aws.wafregional.GeoMatchSet("geoMatchSet", geo_match_constraints=[
            aws.wafregional.GeoMatchSetGeoMatchConstraintArgs(
                type="Country",
                value="US",
            ),
            aws.wafregional.GeoMatchSetGeoMatchConstraintArgs(
                type="Country",
                value="CA",
            ),
        ])
        ```

        ## Import

        WAF Regional Geo Match Set can be imported using the id, e.g.,

        ```sh
         $ pulumi import aws:wafregional/geoMatchSet:GeoMatchSet geo_match_set a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GeoMatchSetGeoMatchConstraintArgs']]]] geo_match_constraints: The Geo Match Constraint objects which contain the country that you want AWS WAF to search for.
        :param pulumi.Input[str] name: The name or description of the Geo Match Set.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[GeoMatchSetArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a WAF Regional Geo Match Set Resource

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        geo_match_set = aws.wafregional.GeoMatchSet("geoMatchSet", geo_match_constraints=[
            aws.wafregional.GeoMatchSetGeoMatchConstraintArgs(
                type="Country",
                value="US",
            ),
            aws.wafregional.GeoMatchSetGeoMatchConstraintArgs(
                type="Country",
                value="CA",
            ),
        ])
        ```

        ## Import

        WAF Regional Geo Match Set can be imported using the id, e.g.,

        ```sh
         $ pulumi import aws:wafregional/geoMatchSet:GeoMatchSet geo_match_set a1b2c3d4-d5f6-7777-8888-9999aaaabbbbcccc
        ```

        :param str resource_name: The name of the resource.
        :param GeoMatchSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GeoMatchSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 geo_match_constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GeoMatchSetGeoMatchConstraintArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GeoMatchSetArgs.__new__(GeoMatchSetArgs)

            __props__.__dict__["geo_match_constraints"] = geo_match_constraints
            __props__.__dict__["name"] = name
        super(GeoMatchSet, __self__).__init__(
            'aws:wafregional/geoMatchSet:GeoMatchSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            geo_match_constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GeoMatchSetGeoMatchConstraintArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'GeoMatchSet':
        """
        Get an existing GeoMatchSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GeoMatchSetGeoMatchConstraintArgs']]]] geo_match_constraints: The Geo Match Constraint objects which contain the country that you want AWS WAF to search for.
        :param pulumi.Input[str] name: The name or description of the Geo Match Set.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GeoMatchSetState.__new__(_GeoMatchSetState)

        __props__.__dict__["geo_match_constraints"] = geo_match_constraints
        __props__.__dict__["name"] = name
        return GeoMatchSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="geoMatchConstraints")
    def geo_match_constraints(self) -> pulumi.Output[Optional[Sequence['outputs.GeoMatchSetGeoMatchConstraint']]]:
        """
        The Geo Match Constraint objects which contain the country that you want AWS WAF to search for.
        """
        return pulumi.get(self, "geo_match_constraints")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name or description of the Geo Match Set.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetLinkResult',
    'AwaitableGetLinkResult',
    'get_link',
    'get_link_output',
]

@pulumi.output_type
class GetLinkResult:
    """
    A collection of values returned by getLink.
    """
    def __init__(__self__, arn=None, bandwidths=None, description=None, global_network_id=None, id=None, link_id=None, provider_name=None, site_id=None, tags=None, type=None):
        if arn and not isinstance(arn, str):
            raise TypeError("Expected argument 'arn' to be a str")
        pulumi.set(__self__, "arn", arn)
        if bandwidths and not isinstance(bandwidths, list):
            raise TypeError("Expected argument 'bandwidths' to be a list")
        pulumi.set(__self__, "bandwidths", bandwidths)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if global_network_id and not isinstance(global_network_id, str):
            raise TypeError("Expected argument 'global_network_id' to be a str")
        pulumi.set(__self__, "global_network_id", global_network_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if link_id and not isinstance(link_id, str):
            raise TypeError("Expected argument 'link_id' to be a str")
        pulumi.set(__self__, "link_id", link_id)
        if provider_name and not isinstance(provider_name, str):
            raise TypeError("Expected argument 'provider_name' to be a str")
        pulumi.set(__self__, "provider_name", provider_name)
        if site_id and not isinstance(site_id, str):
            raise TypeError("Expected argument 'site_id' to be a str")
        pulumi.set(__self__, "site_id", site_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def arn(self) -> str:
        """
        ARN of the link.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter
    def bandwidths(self) -> Sequence['outputs.GetLinkBandwidthResult']:
        """
        Upload speed and download speed of the link as documented below
        """
        return pulumi.get(self, "bandwidths")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the link.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="globalNetworkId")
    def global_network_id(self) -> str:
        return pulumi.get(self, "global_network_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="linkId")
    def link_id(self) -> str:
        return pulumi.get(self, "link_id")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> str:
        """
        Provider of the link.
        """
        return pulumi.get(self, "provider_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> str:
        """
        ID of the site.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        Key-value tags for the link.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Type of the link.
        """
        return pulumi.get(self, "type")


class AwaitableGetLinkResult(GetLinkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLinkResult(
            arn=self.arn,
            bandwidths=self.bandwidths,
            description=self.description,
            global_network_id=self.global_network_id,
            id=self.id,
            link_id=self.link_id,
            provider_name=self.provider_name,
            site_id=self.site_id,
            tags=self.tags,
            type=self.type)


def get_link(global_network_id: Optional[str] = None,
             link_id: Optional[str] = None,
             tags: Optional[Mapping[str, str]] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLinkResult:
    """
    Retrieve information about a link.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.networkmanager.get_link(global_network_id=var["global_network_id"],
        link_id=var["link_id"])
    ```


    :param str global_network_id: ID of the Global Network of the link to retrieve.
    :param str link_id: ID of the specific link to retrieve.
    :param Mapping[str, str] tags: Key-value tags for the link.
    """
    __args__ = dict()
    __args__['globalNetworkId'] = global_network_id
    __args__['linkId'] = link_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aws:networkmanager/getLink:getLink', __args__, opts=opts, typ=GetLinkResult).value

    return AwaitableGetLinkResult(
        arn=__ret__.arn,
        bandwidths=__ret__.bandwidths,
        description=__ret__.description,
        global_network_id=__ret__.global_network_id,
        id=__ret__.id,
        link_id=__ret__.link_id,
        provider_name=__ret__.provider_name,
        site_id=__ret__.site_id,
        tags=__ret__.tags,
        type=__ret__.type)


@_utilities.lift_output_func(get_link)
def get_link_output(global_network_id: Optional[pulumi.Input[str]] = None,
                    link_id: Optional[pulumi.Input[str]] = None,
                    tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLinkResult]:
    """
    Retrieve information about a link.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.networkmanager.get_link(global_network_id=var["global_network_id"],
        link_id=var["link_id"])
    ```


    :param str global_network_id: ID of the Global Network of the link to retrieve.
    :param str link_id: ID of the specific link to retrieve.
    :param Mapping[str, str] tags: Key-value tags for the link.
    """
    ...
